"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DistributedTask = void 0;
const backfill_1 = require("../cache/backfill");
class DistributedTask {
    constructor(id, cwd, config, workerQueue, logger) {
        this.id = id;
        this.cwd = cwd;
        this.config = config;
        this.workerQueue = workerQueue;
        this.logger = logger;
    }
    async getRemoteCache(remoteJobResults) {
        if (!remoteJobResults) {
            return;
        }
        const { hash, id, cwd, outputGlob } = remoteJobResults;
        if (hash && id && cwd) {
            const cacheOptions = Object.assign(Object.assign({}, this.config.cacheOptions), { outputGlob: outputGlob || this.config.cacheOptions.outputGlob });
            await (0, backfill_1.cacheFetch)(hash, id, cwd, cacheOptions);
        }
    }
    async run() {
        const { id, logger } = this;
        return new Promise(async (resolve, reject) => {
            if (await this.workerQueue.closing()) {
                return;
            }
            const job = await this.workerQueue.addJob(id);
            if (job) {
                const completeHandler = async ({ jobId, returnvalue }) => {
                    job.off("completed", completeHandler);
                    job.off("failed", failedHandler);
                    await this.getRemoteCache(Object.assign(Object.assign({}, returnvalue), { cwd: this.cwd }));
                    resolve();
                };
                const failedHandler = ({ jobId, failedReason }) => {
                    job.off("completed", completeHandler);
                    job.off("failed", failedHandler);
                    logger.error(failedReason);
                    reject();
                };
                job.on("completed", completeHandler);
                job.on("failed", failedHandler);
            }
        });
    }
}
exports.DistributedTask = DistributedTask;
//# sourceMappingURL=DistributedTask.js.map